#ifndef NETWORKHELPER_H
#define NETWORKHELPER_H

#include <QtNetwork/QNetworkAccessManager>
#include <QtNetwork/QNetworkRequest>
#include <QtNetwork/QNetworkReply>
#include <QtXml>
#include <QRegExp>
#include <QDebug>
#include <QList>
#include <QUrl>
#include <QObject>
#include <QIODevice>
#include <QByteArray>

#define DBG

class QNetworkAccessManager;
class QNetworkReply;
class QNetworkRequest;

class NetworkHelper : public QObject {
    Q_OBJECT

//    Q_PROPERTY(bool isDownloading
//               READ isDownloading
//               NOTIFY downloadingChanged)

public:
    explicit NetworkHelper(QObject *parent = 0);

    void setNetworkAccessManager(QNetworkAccessManager *manager);
    int doWebRequest(QString method, QString itemURL, int params);

    void login(QString username, QString password);
    void loadAllPortfolio();

signals:

private:
    QNetworkAccessManager *nam;
    QNetworkReply *reply;
    QString auth;
    bool downloading;

private slots:
    void parseAuth();

signals:
    void statusChanged(const QString &status);

};



#endif // NETWORKHELPER_H
